@@ -34,7 +34,7 @@ typedef struct {
         GtkSpinButton *timeout_spinbutton, *graph_size_spinbutton;
         GtkTable *globals_table;
         GtkHSeparator *globals_separator;
-        GtkComboBox *display_mode_combo_box, *layout_mode_combo_box, *temperature_scale_combo_box;
+        GtkComboBoxText *display_mode_combo_box, *layout_mode_combo_box, *temperature_scale_combo_box;
         GtkLabel *timeout_label, *display_mode_label, *layout_mode_label, *temperature_scale_label, *graph_size_label, *update_header, *display_header;
         GtkAdjustment *timeout_adjust, *graph_size_adjust;
 
